@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.12.14 00:00:00                  #
+# Updated Date: 2025.08.11 14:00:00                  #
 # ================================================== #
 
 from typing import Any
@@ -85,4 +85,16 @@ class Worker(BaseWorker):
             if self.restart:
                 self.docker.restart()
         except Exception as e:
-            self.signals.error.emit(e)
\ No newline at end of file
+            self.signals.error.emit(e)
+        finally:
+            self.cleanup()
+
+    def cleanup(self):
+        """Cleanup resources after worker execution."""
+        sig = self.signals
+        self.signals = None
+        if sig is not None:
+            try:
+                sig.deleteLater()
+            except RuntimeError:
+                pass
\ No newline at end of file
