@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.09.14 20:00:00                  #
+# Updated Date: 2025.09.17 05:00:00                  #
 # ================================================== #
 
 import gc
@@ -182,6 +182,7 @@ class Renderer(BaseRenderer):
         self._stream_timer: dict[int, QTimer] = {}
         self._stream_header: dict[int, str] = {}
         self._stream_last_flush: dict[int, float] = {}
+        self._stream_last_cleanup: float = 0.0
 
         # Pid-related cached methods
         self._get_pid = None
@@ -496,6 +497,7 @@ class Renderer(BaseRenderer):
         Soft cleanup, called after each context is done.
         """
         try:
+            gc.collect()
             malloc_trim_linux()
         except Exception:
             pass
@@ -1248,7 +1250,10 @@ class Renderer(BaseRenderer):
         html = self.body.get_html(pid)
         node = self.get_output_node_by_pid(pid)
         if node is not None:
-            node.setHtml(html, baseUrl="file://")
+            try:
+                node.setHtml(html, baseUrl="file://")
+            except Exception as e:
+                print("[Renderer] flush error:", e)
 
     def fresh(self, meta: Optional[CtxMeta] = None, force: bool = False):
         """
@@ -1274,12 +1279,7 @@ class Renderer(BaseRenderer):
                     pass
             self._bridge_ready[pid] = False
             self._pending_nodes[pid] = []
-            node.hide()
-            p = node.page()
-            p.triggerAction(QWebEnginePage.Stop)
-            p.setUrl(QUrl("about:blank"))
-            p.history().clear()
-            p.setLifecycleState(QWebEnginePage.LifecycleState.Discarded)
+            node.unload()  # unload web page
             self._stream_reset(pid)
             self.pids[pid].clear(all=True)
             self.pids[pid].loaded = False
@@ -1294,20 +1294,20 @@ class Renderer(BaseRenderer):
         :param meta: context meta
         """
         tab = node.get_tab()
-        tab.delete_ref(node)
+        if tab is None:
+            return
         layout = tab.child.layout()
-        layout.removeWidget(node)
+        tab.unwrap(node)
         self.window.ui.nodes['output'].pop(tab.pid, None)
 
-        node.on_delete()
-
         view = ChatWebOutput(self.window)
         view.set_tab(tab)
         view.set_meta(meta)
         view.signals.save_as.connect(self.window.controller.chat.render.handle_save_as)
         view.signals.audio_read.connect(self.window.controller.chat.render.handle_audio_read)
 
-        layout.addWidget(view)
+        layout.addWidget(view)  # tab body layout
+        tab.add_ref(view)
         view.setVisible(True)
         self.window.ui.nodes['output'][tab.pid] = view
         try:
@@ -1324,7 +1324,7 @@ class Renderer(BaseRenderer):
         :return: output node or None
         """
         if self._get_output_node_by_meta is None:
-            self._get_output_node_by_meta = self.window.core.ctx.output.get_output_node_by_meta
+            self._get_output_node_by_meta = self.window.core.ctx.output.get_current
         return self._get_output_node_by_meta(meta)
 
     def get_output_node_by_pid(self, pid: Optional[int]) -> Optional[ChatWebOutput]:
@@ -1335,7 +1335,7 @@ class Renderer(BaseRenderer):
         :return: output node or None
         """
         if self._get_output_node_by_pid is None:
-            self._get_output_node_by_pid = self.window.core.ctx.output.get_output_node_by_pid
+            self._get_output_node_by_pid = self.window.core.ctx.output.get_by_pid
         return self._get_output_node_by_pid(pid)
 
     def get_input_node(self) -> ChatInput:
@@ -1866,29 +1866,19 @@ class Renderer(BaseRenderer):
         data = buf.get_and_clear()
         name = self._stream_header.get(pid, "") or ""
 
-        try:
-            br = getattr(node.page(), "bridge", None)
-            if br is not None and hasattr(br, "chunk"):
-                br.chunk.emit(name, data, "text_delta")
-            else:
-                node.page().runJavaScript(
-                    f"if (typeof window.appendStream !== 'undefined') appendStream({self.to_json(name)},{self.to_json(data)});"
-                )
-        except Exception:
-            try:
-                node.page().runJavaScript(
-                    f"if (typeof window.appendStream !== 'undefined') appendStream({self.to_json(name)},{self.to_json(data)});"
-                )
-            except Exception:
-                pass
+        node.page().bridge.chunk.emit(name, data, "text_delta")
 
         try:
-            if len(data) >= (256 * 1024):
+            del data
+            # auto GC cleanup after some time
+            now = monotonic()
+            last = self._stream_last_cleanup
+            if now - last > 120.0:
                 self.auto_cleanup_soft()
+                self._stream_last_cleanup = now
         except Exception:
             pass
 
-        del data
         self._stream_last_flush[pid] = monotonic()
 
     def eval_js(self, script: str):
