@@ -6,21 +6,17 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.07.17 19:00:00                  #
+# Updated Date: 2025.08.06 01:00:00                  #
 # ================================================== #
+
 import base64
 import os
 import json
 import re
 import time
-
-import docker
 import io
 import tarfile
 
-from jupyter_client import BlockingKernelClient
-from docker.errors import DockerException
-
 class DockerKernel:
 
     NOT_READY_MSG = "IPython kernel is not initialized... try to restart the kernel with: /restart"
@@ -96,6 +92,7 @@ class DockerKernel:
 
     def is_image(self):
         """Check if the Docker image for the IPython kernel exists."""
+        import docker.errors
         client = self.get_docker_client()
         try:
             client.images.get(self.get_image_name())
@@ -132,6 +129,7 @@ class DockerKernel:
         :param force: Force reinitialization.
         :param auto_init: Automatically initialize the kernel if not initialized after error.
         """
+        from jupyter_client import BlockingKernelClient
         if self.initialized and not force:
             return
 
@@ -173,12 +171,13 @@ class DockerKernel:
         except FileExistsError:
             pass
 
-    def get_docker_client(self) -> docker.DockerClient:
+    def get_docker_client(self):
         """
         Get the Docker client.
 
         :return: Docker client.
         """
+        import docker
         return docker.from_env()
 
     def prepare_conn(self):
@@ -241,6 +240,7 @@ class DockerKernel:
 
         :param name: Container name.
         """
+        import docker.errors
         client = self.get_docker_client()
         try:
             container = client.containers.get(name)
@@ -256,6 +256,7 @@ class DockerKernel:
         :param name: Container name.
         :return: True if the container was started successfully, False otherwise.
         """
+        import docker.errors
         client = self.get_docker_client()
         ports = self.get_ports()
         # at first, check for image
@@ -297,6 +298,7 @@ class DockerKernel:
 
         :param name: Container name.
         """
+        import docker.errors
         client = self.get_docker_client()
         try:
             client.containers.get(name)
@@ -312,6 +314,7 @@ class DockerKernel:
 
         :param name: Container name.
         """
+        import docker.errors
         client = self.get_docker_client()
         try:
             container = client.containers.get(name)
@@ -463,6 +466,7 @@ class DockerKernel:
 
     def restart_kernel(self) -> bool:
         """Restart kernel"""
+        from jupyter_client import BlockingKernelClient
         if self.restarting:
             self.log("Kernel is already restarting.")
             return False
@@ -503,6 +507,8 @@ class DockerKernel:
 
         :return: True if installed
         """
+        import docker
+        from docker.errors import DockerException
         try:
             if self.client is None:
                 client = docker.from_env()
