@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.11.26 02:00:00                  #
+# Updated Date: 2025.08.24 23:00:00                  #
 # ================================================== #
 
 from PySide6.QtCore import Qt
@@ -17,8 +17,6 @@ from pygpt_net.ui.widget.dialog.base import BaseDialog
 from pygpt_net.ui.widget.image.display import ImageLabel
 from pygpt_net.utils import trans
 
-import pygpt_net.icons_rc
-
 class DialogSpawner:
     def __init__(self, window=None):
         """
@@ -37,9 +35,13 @@ class DialogSpawner:
         :param id: dialog id
         :return: BaseDialog instance
         """
-        source = ImageLabel(self.window, self.path)
+        dialog = ImageViewerDialog(self.window, self.id)
+        dialog.disable_geometry_store = True  # disable geometry store
+        dialog.id = id
+
+        source = ImageLabel(dialog, self.path)
         source.setVisible(False)
-        pixmap = ImageLabel(self.window, self.path)
+        pixmap = ImageLabel(dialog, self.path)
         pixmap.setSizePolicy(QSizePolicy(QSizePolicy.Ignored, QSizePolicy.Ignored))
 
         row = QHBoxLayout()
@@ -48,11 +50,7 @@ class DialogSpawner:
         layout = QVBoxLayout()
         layout.addLayout(row)
 
-        dialog = ImageViewerDialog(self.window, self.id)
-        dialog.disable_geometry_store = True  # disable geometry store
-        dialog.id = id
         dialog.append_layout(layout)
-        dialog.setLayout(layout)
         dialog.source = source
         dialog.pixmap = pixmap
 
@@ -74,9 +72,14 @@ class ImageViewerDialog(BaseDialog):
         self.menu_bar = None
         self.file_menu = None
         self.actions = {}
-        self.resizeEvent = self.onResizeEvent  # resize event to adjust the pixmap
         self.source = None
         self.pixmap = None
+        self._last_src_key = 0
+        self._last_target_size = None
+        self._icon_add = QIcon(":/icons/add.svg")
+        self._icon_folder = QIcon(":/icons/folder.svg")
+        self._icon_save = QIcon(":/icons/save.svg")
+        self._icon_logout = QIcon(":/icons/logout.svg")
 
     def append_layout(self, layout):
         """
@@ -84,23 +87,29 @@ class ImageViewerDialog(BaseDialog):
 
         :param layout: layout
         """
-        layout.setMenuBar(self.setup_menu())  # attach menu
+        layout.setMenuBar(self.setup_menu())
         self.setLayout(layout)
 
-    def onResizeEvent(self, event):
+    def resizeEvent(self, event):
         """
         Resize event to adjust the pixmap on window resizing
 
         :param event: resize event
         """
-        if self.source.pixmap() and not self.source.pixmap().isNull():
-            self.pixmap.setPixmap(
-                self.source.pixmap().scaled(
-                    self.pixmap.size(),
-                    Qt.KeepAspectRatio,
-                    Qt.SmoothTransformation
+        src = self.source.pixmap() if self.source is not None else None
+        if src and not src.isNull() and self.pixmap is not None:
+            target_size = self.pixmap.size()
+            key = src.cacheKey()
+            if key != self._last_src_key or target_size != self._last_target_size:
+                self.pixmap.setPixmap(
+                    src.scaled(
+                        target_size,
+                        Qt.KeepAspectRatio,
+                        Qt.SmoothTransformation
+                    )
                 )
-            )
+                self._last_src_key = key
+                self._last_target_size = target_size
         super(ImageViewerDialog, self).resizeEvent(event)
 
     def setup_menu(self) -> QMenuBar:
@@ -109,44 +118,38 @@ class ImageViewerDialog(BaseDialog):
 
         :return: QMenuBar
         """
-        self.menu_bar = QMenuBar()
+        self.menu_bar = QMenuBar(self)
         self.file_menu = self.menu_bar.addMenu(trans("menu.file"))
 
-        # new
-        self.actions["new"] = QAction(QIcon(":/icons/add.svg"), trans("action.new"))
+        self.actions["new"] = QAction(self._icon_add, trans("action.new"), self)
         self.actions["new"].triggered.connect(
-            lambda: self.window.tools.get("viewer").new()
+            lambda checked=False: self.window.tools.get("viewer").new()
         )
 
-        # open
-        self.actions["open"] = QAction(QIcon(":/icons/folder.svg"), trans("action.open"))
+        self.actions["open"] = QAction(self._icon_folder, trans("action.open"), self)
         self.actions["open"].triggered.connect(
-            lambda: self.window.tools.get("viewer").open_file(self.id, auto_close=True)
+            lambda checked=False: self.window.tools.get("viewer").open_file(self.id, auto_close=True)
         )
 
-        # open (new window)
-        self.actions["open_new"] = QAction(QIcon(":/icons/folder.svg"), trans("action.open_new_window"))
+        self.actions["open_new"] = QAction(self._icon_folder, trans("action.open_new_window"), self)
         self.actions["open_new"].triggered.connect(
-            lambda: self.window.tools.get("viewer").open_file(self.id, auto_close=False)
+            lambda checked=False: self.window.tools.get("viewer").open_file(self.id, auto_close=False)
         )
 
-        # save as
-        self.actions["save_as"] = QAction(QIcon(":/icons/save.svg"), trans("action.save_as"))
+        self.actions["save_as"] = QAction(self._icon_save, trans("action.save_as"), self)
         self.actions["save_as"].triggered.connect(
-            lambda: self.window.tools.get("viewer").save_by_id(self.id)
+            lambda checked=False: self.window.tools.get("viewer").save_by_id(self.id)
         )
 
-        # exit
-        self.actions["exit"] = QAction(QIcon(":/icons/logout.svg"), trans("menu.file.exit"))
+        self.actions["exit"] = QAction(self._icon_logout, trans("menu.file.exit"), self)
         self.actions["exit"].triggered.connect(
-            lambda: self.window.tools.get("viewer").close_preview(self.id)
+            lambda checked=False: self.window.tools.get("viewer").close_preview(self.id)
         )
 
-        # add actions
         self.file_menu.addAction(self.actions["new"])
         self.file_menu.addAction(self.actions["open"])
         self.file_menu.addAction(self.actions["open_new"])
         self.file_menu.addAction(self.actions["save_as"])
         self.file_menu.addAction(self.actions["exit"])
 
-        return self.menu_bar
+        return self.menu_bar
\ No newline at end of file
