@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.11.17 03:00:00                  #
+# Updated Date: 2025.09.05 18:00:00                  #
 # ================================================== #
 
-from .toolbox import *
\ No newline at end of file
+from .toolbox import ToolboxMain
\ No newline at end of file
