@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.09.12 20:00:00                  #
+# Updated Date: 2025.09.19 00:00:00                  #
 # ================================================== #
 
 from PySide6.QtGui import QAction
@@ -39,6 +39,7 @@ class Debug:
             'attachments',
             'assistants',
             'agent',
+            # 'agent_builder',
             'events',
             'indexes',
             'ui',
@@ -61,6 +62,7 @@ class Debug:
                   'attachments',
                   'assistants',
                   'agent',
+                  # 'agent_builder',
                   'events',
                   'indexes',
                   'ui',
@@ -98,6 +100,7 @@ class Debug:
         menu.addActions(
             [
                 m['debug.agent'],
+                # m['debug.agent_builder'],
                 m['debug.assistants'],
                 m['debug.attachments'],
                 m['debug.config'],
@@ -113,4 +116,39 @@ class Debug:
             ]
         )
 
+        # add separator and sub-menu with Chrome debug
+        menu.addSeparator()
+
+        # Sub-menu "Chrome"
+        m['menu.debug.chrome'] = menu.addMenu("Chromium")
+        chrome_urls = {
+            'sandbox': ('Sandbox', 'chrome://sandbox'),
+            'gpu': ('GPU', 'chrome://gpu'),
+            'version': ('Version', 'chrome://version'),
+            'flags': ('Flags', 'chrome://flags'),
+            'components': ('Components', 'chrome://components'),
+            'policy': ('Policy', 'chrome://policy'),
+            'dns': ('DNS', 'chrome://dns'),
+            'net_export': ('Net Export', 'chrome://net-export'),
+            'media_internals': ('Media Internals', 'chrome://media-internals'),
+            'webrtc_internals': ('WebRTC Internals', 'chrome://webrtc-internals'),
+            'discards': ('Discards (Tab Discarding)', 'chrome://discards'),
+            'crashes': ('Crashes', 'chrome://crashes'),
+            'histograms': ('Histograms', 'chrome://histograms'),
+            'process_internals': ('Process Internals', 'chrome://process-internals'),
+            'tracing': ('Tracing', 'chrome://tracing'),
+            'chrome_urls': ('All Chrome URLs', 'chrome://chrome-urls'),
+        }
+
+        for key, (label, url) in chrome_urls.items():
+            action_key = f"debug.chrome.{key}"
+            m[action_key] = QAction(label, win)
+            m[action_key].triggered.connect(lambda _=False, u=url: dbg.open_chrome_debug(u))
+            m['menu.debug.chrome'].addAction(m[action_key])
+
+        # add open devtools action
+        m['debug.chrome.devtools'] = QAction("Open DevTools", win)
+        m['debug.chrome.devtools'].triggered.connect(dbg.open_dev_tools)
+        menu.addAction(m['debug.chrome.devtools'])
+
         m['debug.render'].setChecked(bool(win.core.config.get('debug.render')))
\ No newline at end of file
