@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.09.03 00:00:00                  #
+# Updated Date: 2025.09.22 12:00:00                  #
 # ================================================== #
 
 from typing import Optional
@@ -30,10 +30,12 @@ class ChatInput(QTextEdit):
     ICON_PASTE = QIcon(":/icons/paste.svg")
     ICON_VOLUME = QIcon(":/icons/volume.svg")
     ICON_SAVE = QIcon(":/icons/save.svg")
-    ICON_ATTACHMENT = QIcon(":/icons/add.svg")
-    #ICON_ATTACHMENT = QIcon(":/icons/attachment.svg")
+    # ICON_ATTACHMENT = QIcon(":/icons/add.svg")
+    ICON_ATTACHMENT = QIcon(":/icons/attachment.svg")
     ICON_MIC_ON = QIcon(":/icons/mic.svg")
     ICON_MIC_OFF = QIcon(":/icons/mic_off.svg")
+    ICON_WEB_ON = QIcon(":/icons/web_on.svg")
+    ICON_WEB_OFF = QIcon(":/icons/web_off.svg")
 
     def __init__(self, window=None):
         """
@@ -87,6 +89,16 @@ class ChatInput(QTextEdit):
             callback=self.action_toggle_mic,
             visible=False,
         )
+        # Add a web search toggle button
+        self.add_icon(
+            key="web",
+            icon=self.ICON_WEB_OFF,
+            alt_icon=self.ICON_WEB_ON,
+            tooltip=trans('icon.remote_tool.web'),
+            alt_tooltip=trans('icon.remote_tool.web'),
+            callback=self.action_toggle_web,
+            visible=True,
+        )
 
         # Apply initial margins (top padding + left space for icons)
         self._apply_margins()
@@ -106,8 +118,15 @@ class ChatInput(QTextEdit):
         self._auto_timer.setSingleShot(True)
         self._auto_timer.timeout.connect(self._auto_resize_tick)
 
-        # Trigger auto-resize on text changes (tokens update stays intact)
-        self.textChanged.connect(self._schedule_auto_resize)
+        self._tokens_timer = QTimer(self)
+        self._tokens_timer.setSingleShot(True)
+        self._tokens_timer.setInterval(1500)
+        self._tokens_timer.timeout.connect(self.window.controller.ui.update_tokens)
+        self.textChanged.connect(self._on_text_changed_tokens)
+
+    def _on_text_changed_tokens(self):
+        """Schedule token count update with debounce."""
+        self._tokens_timer.start()
 
     def _apply_text_top_padding(self):
         """Apply extra top padding inside the text area by using viewport margins."""
@@ -214,27 +233,29 @@ class ChatInput(QTextEdit):
     def keyPressEvent(self, event):
         """
         Key press event
-
-        :param event: key event
         """
         handled = False
         key = event.key()
+
         if key in (Qt.Key_Return, Qt.Key_Enter):
             mode = self.window.core.config.get('send_mode')
             if mode > 0:
-                modifiers = event.modifiers()
+                mods = event.modifiers()
+                has_shift_or_ctrl = bool(mods & (Qt.ShiftModifier | Qt.ControlModifier))
+
                 if mode == 2:
-                    if modifiers == Qt.ShiftModifier or modifiers == Qt.ControlModifier:
+                    if has_shift_or_ctrl:
                         self.window.controller.chat.input.send_input()
                         handled = True
                 else:
-                    if modifiers != Qt.ShiftModifier and modifiers != Qt.ControlModifier:
+                    if not has_shift_or_ctrl:
                         self.window.controller.chat.input.send_input()
                         handled = True
+
                 self.setFocus()
-                # Collapse to minimum after sending
                 if handled:
                     QTimer.singleShot(0, self.collapse_to_min)
+
         elif key == Qt.Key_Escape and self.window.controller.ctx.extra.is_editing():
             self.window.controller.ctx.extra.edit_cancel()
             handled = True
@@ -281,6 +302,10 @@ class ChatInput(QTextEdit):
         """Toggle microphone (button click)."""
         self.window.dispatch(Event(Event.AUDIO_INPUT_RECORD_TOGGLE))
 
+    def action_toggle_web(self):
+        """Toggle web search (button click)."""
+        self.window.controller.chat.remote_tools.toggle('web_search')
+
     # -------------------- Left icon bar  --------------------
     # - Add icons: add_icon(...) or add_icons([...])
     # - Show/hide: set_icon_visible(key, bool)
